@@ -316,7 +316,6 @@ magnifier_main_refresh_all (gpointer data)
 #ifdef DEBUG_REFRESH
 	fprintf (stderr, "refreshing %d regions\n", regions->_length);
 #endif
-#undef DEBUG_REFRESH
 
 	properties = GNOME_Magnifier_Magnifier_getProperties (BONOBO_OBJREF (magnifier), &ev);
 
@@ -328,10 +327,10 @@ magnifier_main_refresh_all (gpointer data)
 	}
 
 	dirty_bounds = (GNOME_Magnifier_RectBounds *) dirty_bounds_any->_value;
-	/*
+
 	  fprintf (stderr, "region to update: %d %d %d %d\n",
 		 dirty_bounds->x1, dirty_bounds->y1, dirty_bounds->x2, dirty_bounds->y2);
-	*/
+
 	for (i = 0; i < regions->_length; ++i)
 		GNOME_Magnifier_ZoomRegion_markDirty (
 			regions->_buffer [i], dirty_bounds, &ev);
@@ -369,6 +368,8 @@ main (int argc, char** argv)
   while (poptGetNextOpt (ctx) >= 0)
 	/**/;
 
+  poptFreeContext (ctx);
+
   /** 
    * slight hack, we set $DISPLAY if --target-display is set.
    * this is because I don't think GTK+ works well with across multiple 
@@ -394,7 +395,6 @@ main (int argc, char** argv)
   }
 
   magnifier = magnifier_new (global_options.is_override_redirect);
-  fprintf (stderr, "New magnifier created.\n");
   
   properties = GNOME_Magnifier_Magnifier_getProperties (
 	  BONOBO_OBJREF (magnifier), &ev);
@@ -474,7 +474,6 @@ main (int argc, char** argv)
   {
 	  int scroll_policy;
 	  
-	  fprintf (stderr, "Creating an initial zoom region.\n");
 	  init_rect_bounds (roi, 0, 0, 100, 100);
 	  init_rect_bounds (viewport, 0, 0, screen_width, screen_height);
 	  zoom_region =
@@ -572,6 +571,6 @@ main (int argc, char** argv)
   
   if (pan_handle)
 	  g_source_remove (pan_handle);
-  
+
   return 0;
 }
